import { AccountAddress, Chain, ChainAddress, ChainsConfig, Contracts, Network, TokenAddress } from "@wormhole-foundation/sdk-connect";
import type { EvmChains, EvmPlatformType } from "@wormhole-foundation/sdk-evm";
import { EvmUnsignedTransaction } from "@wormhole-foundation/sdk-evm";
import "@wormhole-foundation/sdk-evm-core";
import { Ntt, NttTransceiver, WormholeNttTransceiver } from "@wormhole-foundation/sdk-definitions-ntt";
import type { Provider, TransactionRequest } from "ethers";
import { ethers_contracts } from "./index.js";
export declare class EvmNttWormholeTranceiver<N extends Network, C extends EvmChains> implements NttTransceiver<N, C, WormholeNttTransceiver.VAA> {
    readonly manager: EvmNtt<N, C>;
    readonly address: string;
    transceiver: ethers_contracts.WormholeTransceiver;
    constructor(manager: EvmNtt<N, C>, address: string);
    encodeFlags(skipRelay: boolean): Uint8Array;
    setPeer(peer: ChainAddress<C>): AsyncGenerator<EvmUnsignedTransaction<N, C>, void, unknown>;
    receive(attestation: WormholeNttTransceiver.VAA): AsyncGenerator<EvmUnsignedTransaction<N, C>, void, unknown>;
    isWormholeRelayingEnabled(destChain: Chain): Promise<boolean>;
    isSpecialRelayingEnabled(destChain: Chain): Promise<boolean>;
}
export declare class EvmNtt<N extends Network, C extends EvmChains> implements Ntt<N, C> {
    readonly network: N;
    readonly chain: C;
    readonly provider: Provider;
    readonly contracts: Contracts & {
        ntt?: Ntt.Contracts;
    };
    tokenAddress: string;
    readonly chainId: bigint;
    manager: ethers_contracts.NttManager;
    xcvrs: EvmNttWormholeTranceiver<N, C>[];
    managerAddress: string;
    constructor(network: N, chain: C, provider: Provider, contracts: Contracts & {
        ntt?: Ntt.Contracts;
    });
    static fromRpc<N extends Network>(provider: Provider, config: ChainsConfig<N, EvmPlatformType>): Promise<EvmNtt<N, EvmChains>>;
    private encodeFlags;
    getCustodyAddress(): Promise<string>;
    quoteDeliveryPrice(dstChain: Chain): Promise<[bigint[], bigint]>;
    setPeer(peer: ChainAddress<C>, tokenDecimals: number, inboundLimit: bigint): AsyncGenerator<EvmUnsignedTransaction<N, C>, void, unknown>;
    setWormholeTransceiverPeer(peer: ChainAddress<C>): AsyncGenerator<EvmUnsignedTransaction<N, C>, void, unknown>;
    transfer(sender: AccountAddress<C>, amount: bigint, destination: ChainAddress, queue: boolean): AsyncGenerator<EvmUnsignedTransaction<N, C>>;
    redeem(attestations: Ntt.Attestation[]): AsyncGenerator<EvmUnsignedTransaction<N, C>, void, unknown>;
    getCurrentOutboundCapacity(): Promise<bigint>;
    getCurrentInboundCapacity(fromChain: Chain): Promise<bigint>;
    getRateLimitDuration(): Promise<bigint>;
    getInboundQueuedTransfer(fromChain: Chain, transceiverMessage: Ntt.Message): Promise<Ntt.InboundQueuedTransfer<C> | null>;
    completeInboundQueuedTransfer(fromChain: Chain, transceiverMessage: Ntt.Message, token: TokenAddress<C>, payer?: AccountAddress<C>): AsyncGenerator<EvmUnsignedTransaction<N, C>, void, unknown>;
    createUnsignedTx(txReq: TransactionRequest, description: string, parallelizable?: boolean): EvmUnsignedTransaction<N, C>;
}
//# sourceMappingURL=ntt.d.ts.map